==> styled-components-0.0.2.tgz: package/lib/constructors/test/css.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral([''], ['']),
    _templateObject2 = _taggedTemplateLiteral(['this aint css'], ['this aint css']),
    _templateObject3 = _taggedTemplateLiteral(['🔥🔥😎'], ['🔥🔥😎']),
    _templateObject4 = _taggedTemplateLiteral(['background:red;'], ['background:red;']),
    _templateObject5 = _taggedTemplateLiteral(['background: red;'], ['background: red;']),
    _templateObject6 = _taggedTemplateLiteral(['flex-grow: 1;'], ['flex-grow: 1;']),
    _templateObject7 = _taggedTemplateLiteral(['flexGrow: 1;'], ['flexGrow: 1;']),
    _templateObject8 = _taggedTemplateLiteral(['flex-grow: 1;\nflex-shrink: 0;'], ['flex-grow: 1;\\nflex-shrink: 0;']),
    _templateObject9 = _taggedTemplateLiteral(['flex-grow: 1;\nflex-shrink: 0;\nflex-grow: 0;'], ['flex-grow: 1;\\nflex-shrink: 0;\\nflex-grow: 0;']),
    _templateObject10 = _taggedTemplateLiteral(['\n        background: red;\n        img {\n          background: white;\n        }\n      '], ['\n        background: red;\n        img {\n          background: white;\n        }\n      ']),
    _templateObject11 = _taggedTemplateLiteral(['\n        margin: 0 auto;\n        > img + img, .push-left {\n          margin-left: 1rem;\n        }\n      '], ['\n        margin: 0 auto;\n        > img + img, .push-left {\n          margin-left: 1rem;\n        }\n      ']),
    _templateObject12 = _taggedTemplateLiteral(['\n        text-decoration: none;\n        &:hover {\n          text-decoration: underline;\n        }\n      '], ['\n        text-decoration: none;\n        &:hover {\n          text-decoration: underline;\n        }\n      ']),
    _templateObject13 = _taggedTemplateLiteral(['\n        text-decoration: none;\n        &:hover, &:active, :root.ios & {\n          text-decoration: underline;\n        }\n      '], ['\n        text-decoration: none;\n        &:hover, &:active, :root.ios & {\n          text-decoration: underline;\n        }\n      ']),
    _templateObject14 = _taggedTemplateLiteral(['\n        position: relative;\n        img {\n          position: absolute;\n          &.-in-flow {\n            position: static;\n          }\n        }\n        > span {\n          font-weight: bold;\n          html.ios & {\n            font-weight: normal;\n          }\n        }\n      '], ['\n        position: relative;\n        img {\n          position: absolute;\n          &.-in-flow {\n            position: static;\n          }\n        }\n        > span {\n          font-weight: bold;\n          html.ios & {\n            font-weight: normal;\n          }\n        }\n      ']);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _css = require('../css');

var _css2 = _interopRequireDefault(_css);

var _concat = require('../concat');

var _concat2 = _interopRequireDefault(_concat);

var _rule = require('../rule');

var _rule2 = _interopRequireDefault(_rule);

var _nested = require('../nested');

var _nested2 = _interopRequireDefault(_nested);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

describe('css', function () {
  describe('simple inputs', function () {
    it('should be ok with nonce inputs', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject).rules).toEqual([]);
      (0, _expect2.default)((0, _css2.default)(_templateObject2).rules).toEqual([]);
      (0, _expect2.default)((0, _css2.default)(_templateObject3).rules).toEqual([]);
    });

    it('should handle a single simple rule', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('background', 'red'));
      (0, _expect2.default)((0, _css2.default)(_templateObject4)).toEqual(expected);
      (0, _expect2.default)((0, _css2.default)(_templateObject5)).toEqual(expected);
    });

    it('should handle dashed rules', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'));
      (0, _expect2.default)((0, _css2.default)(_templateObject6)).toEqual(expected);
      (0, _expect2.default)((0, _css2.default)(_templateObject7)).toEqual(expected);
    });

    it('should handle multiple lines', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'), (0, _rule2.default)('flexShrink', '0'));
      (0, _expect2.default)((0, _css2.default)(_templateObject8)).toEqual(expected);
    });

    it('should pass through duplicates', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'), (0, _rule2.default)('flexShrink', '0'), (0, _rule2.default)('flexGrow', '0'));
      (0, _expect2.default)((0, _css2.default)(_templateObject9)).toEqual(expected);
    });
  });

  describe('nesting', function () {
    it('should handle nested tag selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject10)).toEqual((0, _concat2.default)((0, _rule2.default)('background', 'red'), (0, _nested2.default)('img', (0, _rule2.default)('background', 'white'))));
    });

    it('should handle more complex nested tag selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject11)).toEqual((0, _concat2.default)((0, _rule2.default)('margin', '0 auto'), (0, _nested2.default)('> img + img, .push-left', (0, _rule2.default)('marginLeft', '1rem'))));
    });

    it('should pass through pseduo selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject12)).toEqual((0, _concat2.default)((0, _rule2.default)('textDecoration', 'none'), (0, _nested2.default)('&:hover', (0, _rule2.default)('textDecoration', 'underline'))));
    });

    it('should pass through multiple selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject13)).toEqual((0, _concat2.default)((0, _rule2.default)('textDecoration', 'none'), (0, _nested2.default)('&:hover, &:active, :root.ios &', (0, _rule2.default)('textDecoration', 'underline'))));
    });

    it('should properly handle multiple nesting', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject14)).toEqual((0, _concat2.default)((0, _rule2.default)('position', 'relative'), (0, _nested2.default)('img', (0, _rule2.default)('position', 'absolute'), (0, _nested2.default)('&.-in-flow', (0, _rule2.default)('position', 'static'))), (0, _nested2.default)('> span', (0, _rule2.default)('fontWeight', 'bold'), (0, _nested2.default)('html.ios &', (0, _rule2.default)('fontWeight', 'normal')))));
    });
  });
});

==> styled-components-0.0.5.tgz: package/lib/constructors/test/css.test.js <==
'use strict';

var _templateObject = _taggedTemplateLiteral([''], ['']),
    _templateObject2 = _taggedTemplateLiteral(['this aint css'], ['this aint css']),
    _templateObject3 = _taggedTemplateLiteral(['🔥🔥😎'], ['🔥🔥😎']),
    _templateObject4 = _taggedTemplateLiteral(['background:red;'], ['background:red;']),
    _templateObject5 = _taggedTemplateLiteral(['background: red;'], ['background: red;']),
    _templateObject6 = _taggedTemplateLiteral(['flex-grow: 1;'], ['flex-grow: 1;']),
    _templateObject7 = _taggedTemplateLiteral(['flexGrow: 1;'], ['flexGrow: 1;']),
    _templateObject8 = _taggedTemplateLiteral(['flex-grow: 1;\nflex-shrink: 0;'], ['flex-grow: 1;\\nflex-shrink: 0;']),
    _templateObject9 = _taggedTemplateLiteral(['flex-grow: 1;\nflex-shrink: 0;\nflex-grow: 0;'], ['flex-grow: 1;\\nflex-shrink: 0;\\nflex-grow: 0;']),
    _templateObject10 = _taggedTemplateLiteral(['\n        background: red;\n        img {\n          background: white;\n        }\n      '], ['\n        background: red;\n        img {\n          background: white;\n        }\n      ']),
    _templateObject11 = _taggedTemplateLiteral(['\n        margin: 0 auto;\n        > img + img, .push-left {\n          margin-left: 1rem;\n        }\n      '], ['\n        margin: 0 auto;\n        > img + img, .push-left {\n          margin-left: 1rem;\n        }\n      ']),
    _templateObject12 = _taggedTemplateLiteral(['\n        text-decoration: none;\n        &:hover {\n          text-decoration: underline;\n        }\n      '], ['\n        text-decoration: none;\n        &:hover {\n          text-decoration: underline;\n        }\n      ']),
    _templateObject13 = _taggedTemplateLiteral(['\n        text-decoration: none;\n        &:hover, &:active, :root.ios & {\n          text-decoration: underline;\n        }\n      '], ['\n        text-decoration: none;\n        &:hover, &:active, :root.ios & {\n          text-decoration: underline;\n        }\n      ']),
    _templateObject14 = _taggedTemplateLiteral(['\n        position: relative;\n        img {\n          position: absolute;\n          &.-in-flow {\n            position: static;\n          }\n        }\n        > span {\n          font-weight: bold;\n          html.ios & {\n            font-weight: normal;\n          }\n        }\n      '], ['\n        position: relative;\n        img {\n          position: absolute;\n          &.-in-flow {\n            position: static;\n          }\n        }\n        > span {\n          font-weight: bold;\n          html.ios & {\n            font-weight: normal;\n          }\n        }\n      ']),
    _templateObject15 = _taggedTemplateLiteral(['\n        animation: fade-in 1s both;\n        + * {\n          animation: fade-in 1s 1s both;\n        }\n        ~ * {\n          animation: fade-in 1s 2s both;\n        }\n      '], ['\n        animation: fade-in 1s both;\n        + * {\n          animation: fade-in 1s 1s both;\n        }\n        ~ * {\n          animation: fade-in 1s 2s both;\n        }\n      ']),
    _templateObject16 = _taggedTemplateLiteral(['\n        background: red;\n        @media (max-width: 500px) {\n          background: blue;\n        }\n      '], ['\n        background: red;\n        @media (max-width: 500px) {\n          background: blue;\n        }\n      ']),
    _templateObject17 = _taggedTemplateLiteral(['\n        background: red;\n        @media screen and (max-width: 500px) and (min-width: 1000px) {\n          background: blue;\n        }\n      '], ['\n        background: red;\n        @media screen and (max-width: 500px) and (min-width: 1000px) {\n          background: blue;\n        }\n      ']);

var _expect = require('expect');

var _expect2 = _interopRequireDefault(_expect);

var _css = require('../css');

var _css2 = _interopRequireDefault(_css);

var _concat = require('../concat');

var _concat2 = _interopRequireDefault(_concat);

var _rule = require('../rule');

var _rule2 = _interopRequireDefault(_rule);

var _nested = require('../nested');

var _nested2 = _interopRequireDefault(_nested);

var _media = require('../media');

var _media2 = _interopRequireDefault(_media);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _taggedTemplateLiteral(strings, raw) { return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }

describe('css', function () {
  describe('simple inputs', function () {
    it('should be ok with nonce inputs', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject).rules).toEqual([]);
      (0, _expect2.default)((0, _css2.default)(_templateObject2).rules).toEqual([]);
      (0, _expect2.default)((0, _css2.default)(_templateObject3).rules).toEqual([]);
    });

    it('should handle a single simple rule', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('background', 'red'));
      (0, _expect2.default)((0, _css2.default)(_templateObject4)).toEqual(expected);
      (0, _expect2.default)((0, _css2.default)(_templateObject5)).toEqual(expected);
    });

    it('should handle dashed rules', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'));
      (0, _expect2.default)((0, _css2.default)(_templateObject6)).toEqual(expected);
      (0, _expect2.default)((0, _css2.default)(_templateObject7)).toEqual(expected);
    });

    it('should handle multiple lines', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'), (0, _rule2.default)('flexShrink', '0'));
      (0, _expect2.default)((0, _css2.default)(_templateObject8)).toEqual(expected);
    });

    it('should pass through duplicates', function () {
      var expected = (0, _concat2.default)((0, _rule2.default)('flexGrow', '1'), (0, _rule2.default)('flexShrink', '0'), (0, _rule2.default)('flexGrow', '0'));
      (0, _expect2.default)((0, _css2.default)(_templateObject9)).toEqual(expected);
    });
  });

  describe('nesting', function () {
    it('should handle nested tag selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject10)).toEqual((0, _concat2.default)((0, _rule2.default)('background', 'red'), (0, _nested2.default)('img', (0, _rule2.default)('background', 'white'))));
    });

    it('should handle more complex nested tag selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject11)).toEqual((0, _concat2.default)((0, _rule2.default)('margin', '0 auto'), (0, _nested2.default)('> img + img, .push-left', (0, _rule2.default)('marginLeft', '1rem'))));
    });

    it('should pass through pseduo selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject12)).toEqual((0, _concat2.default)((0, _rule2.default)('textDecoration', 'none'), (0, _nested2.default)('&:hover', (0, _rule2.default)('textDecoration', 'underline'))));
    });

    it('should pass through multiple selectors', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject13)).toEqual((0, _concat2.default)((0, _rule2.default)('textDecoration', 'none'), (0, _nested2.default)('&:hover, &:active, :root.ios &', (0, _rule2.default)('textDecoration', 'underline'))));
    });

    it('should properly handle multiple nesting', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject14)).toEqual((0, _concat2.default)((0, _rule2.default)('position', 'relative'), (0, _nested2.default)('img', (0, _rule2.default)('position', 'absolute'), (0, _nested2.default)('&.-in-flow', (0, _rule2.default)('position', 'static'))), (0, _nested2.default)('> span', (0, _rule2.default)('fontWeight', 'bold'), (0, _nested2.default)('html.ios &', (0, _rule2.default)('fontWeight', 'normal')))));
    });

    it('should all nesting syntaxes', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject15)).toEqual((0, _concat2.default)((0, _rule2.default)('animation', 'fade-in 1s both'), (0, _nested2.default)('+ *', (0, _rule2.default)('animation', 'fade-in 1s 1s both')), (0, _nested2.default)('~ *', (0, _rule2.default)('animation', 'fade-in 1s 2s both'))));
    });
  });

  describe('@media', function () {
    it('should handle a simple media query', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject16)).toEqual((0, _concat2.default)((0, _rule2.default)('background', 'red'), (0, _media2.default)('(max-width: 500px)', (0, _rule2.default)('background', 'blue'))));
    });
  });

  describe('@media', function () {
    it('should handle a complex media query', function () {
      (0, _expect2.default)((0, _css2.default)(_templateObject17)).toEqual((0, _concat2.default)((0, _rule2.default)('background', 'red'), (0, _media2.default)('screen and (max-width: 500px) and (min-width: 1000px)', (0, _rule2.default)('background', 'blue'))));
    });
  });
});
